@@ -1,10 +1,12 @@
 library(checkmate)
 library(mlr3)
-lapply(list.files(system.file("testthat", package = "mlr3"), pattern = "^helper.*\\.[rR]$", full.names = TRUE), source)
+lapply(list.files(system.file("testthat", package = "mlr3"),
+  pattern = "^helper.*\\.[rR]$", full.names = TRUE), source)
 
 expect_filter = function(f, task = NULL) {
   expect_r6(f, "Filter",
-    public = c("packages", "feature_types", "task_type", "param_set", "scores",
+    public = c(
+      "packages", "feature_types", "task_type", "param_set", "scores",
       "calculate")
   )
 
