@@ -2,7 +2,9 @@ context("partial scoring")
 
 test_that("praznik 'nfeat' argument works correctly", {
   task = mlr_tasks$get("mtcars")
-  filters = mlr_filters$mget(as.data.table(mlr_filters)[map_lgl(packages, is.element, el = "praznik"), key])
+  filters = mlr_filters$mget(as.data.table(mlr_filters)[map_lgl(packages,
+    is.element,
+    el = "praznik"), key])
   nfeat = 3
 
   for (f in filters) {
